@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005 Alex Murray <pragmatine@gmail.com>
+ * Copyright (C) 2005-2006 Alex Murray <pragmatine@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -149,11 +149,10 @@ gdouble ibm_acpi_sensors_interface_get_sensor_value(const gchar *path,
         gint sensor_value;
         gint cpu_temp, minipci_temp, hdd_temp, gpu_temp, bat0_temp, bat1_temp, unknown0, unknown1;
         gint fan_speed;
-        gchar fan_enabled[9];
 
         if (NULL == (fp = fopen(path, "r"))) {
                 g_set_error(error, IBM_ACPI_FILE_ERROR, IBM_ACPI_FILE_OPEN_ERROR, "Error opening sensor device file %s", path);
-                return;
+                return -1.0;
         }
 
         switch (type) {
@@ -161,20 +160,20 @@ gdouble ibm_acpi_sensors_interface_get_sensor_value(const gchar *path,
                 if (fscanf(fp, "temperatures:   %d %d %d %d %d %d %d %d", &cpu_temp, &minipci_temp, &hdd_temp, &gpu_temp, &bat0_temp, &unknown0, &bat1_temp, &unknown1) != 8) {
                         g_set_error(error, IBM_ACPI_FILE_ERROR, IBM_ACPI_FILE_READ_ERROR, "Error reading from sensor device file %s", path);
                         fclose(fp);
-                        return;
+                        return -1.0;
                 }
 
-                if (strcmp(id, CPU) == 0) {
+                if (g_ascii_strcasecmp(id, CPU) == 0) {
                         sensor_value = cpu_temp;
-                } else if (strcmp(id, MPCI) == 0) {
+                } else if (g_ascii_strcasecmp(id, MPCI) == 0) {
                         sensor_value = minipci_temp;
-                } else if (strcmp(id, HDD) == 0) {
+                } else if (g_ascii_strcasecmp(id, HDD) == 0) {
                         sensor_value = hdd_temp;
-                } else if (strcmp(id, GPU) == 0) {
+                } else if (g_ascii_strcasecmp(id, GPU) == 0) {
                         sensor_value = gpu_temp;
-                } else if (strcmp(id, BAT0) == 0) {
+                } else if (g_ascii_strcasecmp(id, BAT0) == 0) {
                         sensor_value = bat0_temp;
-                } else if (strcmp(id, BAT1) == 0) {
+                } else if (g_ascii_strcasecmp(id, BAT1) == 0) {
                         sensor_value = bat1_temp;
                 }
                 break;
@@ -184,16 +183,19 @@ gdouble ibm_acpi_sensors_interface_get_sensor_value(const gchar *path,
                 if (fscanf(fp, "speed:   %d", &fan_speed) != 1) {
                         g_set_error(error, IBM_ACPI_FILE_ERROR, IBM_ACPI_FILE_READ_ERROR, "Error reading from sensor device file %s", path);
                         fclose(fp);
-                        return;
+                        return -1.0;
                 }
 
-                if (strcmp(id, "FAN") == 0) {
+                if (g_ascii_strcasecmp(id, "FAN") == 0) {
                         sensor_value = fan_speed;
                 }
                 break;
 
         default:
-                g_assert_not_reached();                 
+                g_error("Unknown sensor type passed as parameter to ibm-acpi sensor interface, cannot get value for this sensor");
+                g_set_error(error, IBM_ACPI_FILE_ERROR, IBM_ACPI_FILE_READ_ERROR, "Error reading from sensor device file %s", path);
+                fclose(fp);
+                return -1.0;
         }
 
         fclose(fp);
